#' \code{standby} package
#'
#' Loading screens for Shiny.
#'
#' See the README on
#' \href{https://github.com/rsquaredacademy/standby}{GitHub}
#'
#' @import shiny htmltools grDevices
#' @keywords internal
#' @docType package
#' @name standby
#' @aliases standby-package
"_PACKAGE"
NULL
